Temperature class

Temperature class holds the temperature related info from the API response Properties:

Annotations
  • @JsonSerializable.new()

Constructors

Temperature({required double currentTemperature, required double feelsLike, required double tempMin, required double tempMax, required int pressure, required int humidity})
A class representing temperature-related data.
Temperature.fromJson(Map<String, dynamic> json)
Factory constructor to create a Temperature instance from a JSON map.
factory

Properties

currentTemperature ↔ double
currentTemperature holds the current temperature
getter/setter pair
feelsLike ↔ double
feelsLike Temperature. This temperature parameter accounts for the human perception of weather.
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
humidity ↔ int
humidity holds the humidity value
getter/setter pair
pressure ↔ int
pressure holds the pressure value
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
tempMax ↔ double
tempMax Maximum temperature at the moment of calculation. This is maximal currently observed temperature
getter/setter pair
tempMin ↔ double
tempMin Minimum temperature at the moment of calculation. This is minimal currently observed temperature
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Method to convert a Temperature instance to a JSON map.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited