Wind class

Wind class holds the wind related info from the API response

Annotations
  • @JsonSerializable.new()

Constructors

Wind({required double speed, required double deg, double? gust})
Represents wind data with speed, direction, and optional gust information.
Wind.fromJson(Map<String, dynamic> json)
Creates a new instance of Wind from a JSON object.
factory

Properties

deg ↔ double
deg represents Wind direction, degrees (meteorological)
getter/setter pair
gust ↔ double?
gust represents Wind gust. Unit Default: meter/sec, Metric: meter/sec, Imperial: miles/hour
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
speed ↔ double
speed represents the wind speed
getter/setter pair

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
Converts the Wind object to a JSON object.
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited