LocationView class

A widget that displays the name and geo-coordinates of a location.

The LocationView widget is designed to provide an easy integration for displaying location information, including the name and geo-coordinates (latitude and longitude).

The widget requires a non-null WeatherData object to function properly.

The color parameter can be used to specify the overall color scheme of the widget.

Example usage:

LocationView(
  weatherData: weatherData,
  color: Colors.blue,
)

See also:

  • WeatherData, which provides the necessary data for this widget. Built in widget to support easy integration. The widget lists the name of the location and the geo-coordinates of it
Inheritance

Constructors

LocationView({Key? key, required WeatherData weatherData, Color? color})
A widget that displays the location view with weather data.
const

Properties

color → Color?
With the help of color you specify the overall color scheme.
final
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
weatherData → WeatherData
Please note, in order to use the widget weatherData should not be null.
final

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited